==> apache-pinot-0.9.0-src.tar.gz: apache-pinot-0.9.0-src/pinot-controller/src/main/java/org/apache/pinot/controller/helix/core/assignment/segment/SegmentAssignmentFactory.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pinot.controller.helix.core.assignment.segment;

import org.apache.helix.HelixManager;
import org.apache.pinot.spi.config.table.TableConfig;
import org.apache.pinot.spi.config.table.TableType;


/**
 * Factory for the {@link SegmentAssignment}.
 */
public class SegmentAssignmentFactory {
  private SegmentAssignmentFactory() {
  }

  public static SegmentAssignment getSegmentAssignment(HelixManager helixManager, TableConfig tableConfig) {
    SegmentAssignment segmentAssignment;
    if (tableConfig.getTableType() == TableType.OFFLINE) {
      segmentAssignment =
          tableConfig.isDimTable() ? new OfflineDimTableSegmentAssignment() : new OfflineSegmentAssignment();
    } else {
      segmentAssignment = new RealtimeSegmentAssignment();
    }
    segmentAssignment.init(helixManager, tableConfig);
    return segmentAssignment;
  }
}

==> apache-pinot-0.12.0-src.tar.gz: apache-pinot-0.12.0-src/pinot-controller/src/main/java/org/apache/pinot/controller/helix/core/assignment/segment/SegmentAssignmentFactory.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pinot.controller.helix.core.assignment.segment;

import org.apache.helix.HelixManager;
import org.apache.pinot.spi.config.table.TableConfig;
import org.apache.pinot.spi.config.table.TableType;


/**
 * Factory for the {@link SegmentAssignment}.
 */
public class SegmentAssignmentFactory {
  private SegmentAssignmentFactory() {
  }

  public static SegmentAssignment getSegmentAssignment(HelixManager helixManager, TableConfig tableConfig) {
    SegmentAssignment segmentAssignment;
    if (tableConfig.getTableType() == TableType.OFFLINE) {
      segmentAssignment = new OfflineSegmentAssignment();
    } else {
      segmentAssignment = new RealtimeSegmentAssignment();
    }
    segmentAssignment.init(helixManager, tableConfig);
    return segmentAssignment;
  }
}
